"""add flag to indicate failed si

Revision ID: 342d45db2dc2
Revises: 4461784e248a
Create Date: 2020-10-19 18:33:43.655157+00:00

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = '342d45db2dc2'
down_revision = '4461784e248a'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column('si_aggregated_run', sa.Column('error', sa.Boolean(), nullable=False, server_default='false'))
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('si_aggregated_run', 'error')
    # ### end Alembic commands ###
